# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/asset/namespace.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/asset/namespace.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n yeying/api/asset/namespace.proto\x12\x10yeying.api.asset\x1a\x1fyeying/api/common/message.proto"\x86\x01\n\x16SearchNamespaceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.asset.SearchNamespaceRequestBody"\x89\x01\n\x1aSearchNamespaceRequestBody\x12=\n\tcondition\x18\x01 \x01(\x0b\x32*.yeying.api.asset.SearchNamespaceCondition\x12,\n\x04page\x18\x02 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"(\n\x18SearchNamespaceCondition\x12\x0c\n\x04name\x18\x02 \x01(\t"\x86\x01\n\x16NamespaceDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.asset.NamespaceDetailRequestBody")\n\x1aNamespaceDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x88\x01\n\x17NamespaceDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.asset.NamespaceDetailResponseBody"\x88\x01\n\x1bNamespaceDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\tnamespace\x18\x02 \x01(\x0b\x32#.yeying.api.asset.NamespaceMetadata"\x88\x01\n\x17SearchNamespaceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.asset.SearchNamespaceResponseBody"\x89\x01\n\x1bSearchNamespaceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x37\n\nnamespaces\x18\x02 \x03(\x0b\x32#.yeying.api.asset.NamespaceMetadata"\x86\x01\n\x16\x43reateNamespaceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.asset.CreateNamespaceRequestBody"T\n\x1a\x43reateNamespaceRequestBody\x12\x36\n\tnamespace\x18\x01 \x01(\x0b\x32#.yeying.api.asset.NamespaceMetadata"\x88\x01\n\x17\x43reateNamespaceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.asset.CreateNamespaceResponseBody"\x88\x01\n\x1b\x43reateNamespaceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\tnamespace\x18\x02 \x01(\x0b\x32#.yeying.api.asset.NamespaceMetadata"\x86\x01\n\x16UpdateNamespaceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.asset.UpdateNamespaceRequestBody"T\n\x1aUpdateNamespaceRequestBody\x12\x36\n\tnamespace\x18\x01 \x01(\x0b\x32#.yeying.api.asset.NamespaceMetadata"\x88\x01\n\x17UpdateNamespaceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.asset.UpdateNamespaceResponseBody"\x88\x01\n\x1bUpdateNamespaceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x36\n\tnamespace\x18\x02 \x01(\x0b\x32#.yeying.api.asset.NamespaceMetadata"\x86\x01\n\x16\x44\x65leteNamespaceRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12:\n\x04\x62ody\x18\x02 \x01(\x0b\x32,.yeying.api.asset.DeleteNamespaceRequestBody")\n\x1a\x44\x65leteNamespaceRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x88\x01\n\x17\x44\x65leteNamespaceResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12;\n\x04\x62ody\x18\x02 \x01(\x0b\x32-.yeying.api.asset.DeleteNamespaceResponseBody"P\n\x1b\x44\x65leteNamespaceResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\xa1\x01\n\x11NamespaceMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x14\n\x0cparticipants\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x11\n\tcreatedAt\x18\x06 \x01(\t\x12\x11\n\tupdatedAt\x18\x07 \x01(\t\x12\x11\n\tsignature\x18\x08 \x01(\t2\xf0\x03\n\tNamespace\x12_\n\x06Search\x12(.yeying.api.asset.SearchNamespaceRequest\x1a).yeying.api.asset.SearchNamespaceResponse"\x00\x12_\n\x06\x43reate\x12(.yeying.api.asset.CreateNamespaceRequest\x1a).yeying.api.asset.CreateNamespaceResponse"\x00\x12_\n\x06\x44\x65tail\x12(.yeying.api.asset.NamespaceDetailRequest\x1a).yeying.api.asset.NamespaceDetailResponse"\x00\x12_\n\x06Update\x12(.yeying.api.asset.UpdateNamespaceRequest\x1a).yeying.api.asset.UpdateNamespaceResponse"\x00\x12_\n\x06\x44\x65lete\x12(.yeying.api.asset.DeleteNamespaceRequest\x1a).yeying.api.asset.DeleteNamespaceResponse"\x00\x42\x12Z\x10yeying/api/assetb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.asset.namespace_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\020yeying/api/asset"
    _globals["_SEARCHNAMESPACEREQUEST"]._serialized_start = 88
    _globals["_SEARCHNAMESPACEREQUEST"]._serialized_end = 222
    _globals["_SEARCHNAMESPACEREQUESTBODY"]._serialized_start = 225
    _globals["_SEARCHNAMESPACEREQUESTBODY"]._serialized_end = 362
    _globals["_SEARCHNAMESPACECONDITION"]._serialized_start = 364
    _globals["_SEARCHNAMESPACECONDITION"]._serialized_end = 404
    _globals["_NAMESPACEDETAILREQUEST"]._serialized_start = 407
    _globals["_NAMESPACEDETAILREQUEST"]._serialized_end = 541
    _globals["_NAMESPACEDETAILREQUESTBODY"]._serialized_start = 543
    _globals["_NAMESPACEDETAILREQUESTBODY"]._serialized_end = 584
    _globals["_NAMESPACEDETAILRESPONSE"]._serialized_start = 587
    _globals["_NAMESPACEDETAILRESPONSE"]._serialized_end = 723
    _globals["_NAMESPACEDETAILRESPONSEBODY"]._serialized_start = 726
    _globals["_NAMESPACEDETAILRESPONSEBODY"]._serialized_end = 862
    _globals["_SEARCHNAMESPACERESPONSE"]._serialized_start = 865
    _globals["_SEARCHNAMESPACERESPONSE"]._serialized_end = 1001
    _globals["_SEARCHNAMESPACERESPONSEBODY"]._serialized_start = 1004
    _globals["_SEARCHNAMESPACERESPONSEBODY"]._serialized_end = 1141
    _globals["_CREATENAMESPACEREQUEST"]._serialized_start = 1144
    _globals["_CREATENAMESPACEREQUEST"]._serialized_end = 1278
    _globals["_CREATENAMESPACEREQUESTBODY"]._serialized_start = 1280
    _globals["_CREATENAMESPACEREQUESTBODY"]._serialized_end = 1364
    _globals["_CREATENAMESPACERESPONSE"]._serialized_start = 1367
    _globals["_CREATENAMESPACERESPONSE"]._serialized_end = 1503
    _globals["_CREATENAMESPACERESPONSEBODY"]._serialized_start = 1506
    _globals["_CREATENAMESPACERESPONSEBODY"]._serialized_end = 1642
    _globals["_UPDATENAMESPACEREQUEST"]._serialized_start = 1645
    _globals["_UPDATENAMESPACEREQUEST"]._serialized_end = 1779
    _globals["_UPDATENAMESPACEREQUESTBODY"]._serialized_start = 1781
    _globals["_UPDATENAMESPACEREQUESTBODY"]._serialized_end = 1865
    _globals["_UPDATENAMESPACERESPONSE"]._serialized_start = 1868
    _globals["_UPDATENAMESPACERESPONSE"]._serialized_end = 2004
    _globals["_UPDATENAMESPACERESPONSEBODY"]._serialized_start = 2007
    _globals["_UPDATENAMESPACERESPONSEBODY"]._serialized_end = 2143
    _globals["_DELETENAMESPACEREQUEST"]._serialized_start = 2146
    _globals["_DELETENAMESPACEREQUEST"]._serialized_end = 2280
    _globals["_DELETENAMESPACEREQUESTBODY"]._serialized_start = 2282
    _globals["_DELETENAMESPACEREQUESTBODY"]._serialized_end = 2323
    _globals["_DELETENAMESPACERESPONSE"]._serialized_start = 2326
    _globals["_DELETENAMESPACERESPONSE"]._serialized_end = 2462
    _globals["_DELETENAMESPACERESPONSEBODY"]._serialized_start = 2464
    _globals["_DELETENAMESPACERESPONSEBODY"]._serialized_end = 2544
    _globals["_NAMESPACEMETADATA"]._serialized_start = 2547
    _globals["_NAMESPACEMETADATA"]._serialized_end = 2708
    _globals["_NAMESPACE"]._serialized_start = 2711
    _globals["_NAMESPACE"]._serialized_end = 3207
# @@protoc_insertion_point(module_scope)
